@@ -282,12 +282,18 @@ func main() {
 			}
 		}
 
+		var authURLSuffix string
+		if looksLikeGitHub && pairs["username"] != "" && pairs["username"] != "oauth2" {
+			// https://docs.github.com/en/apps/oauth-apps/building-oauth-apps/authorizing-oauth-apps#1-request-a-users-github-identity
+			authURLSuffix = fmt.Sprintf("&login=%s", pairs["username"])
+		}
+
 		if token == nil {
 			// Generate new token (opens browser, may require user input)
 			if device {
 				token, err = getDeviceToken(ctx, c)
 			} else {
-				token, err = getToken(ctx, c)
+				token, err = getToken(ctx, c, authURLSuffix)
 			}
 			if err != nil {
 				log.Fatalln(err)
@@ -377,7 +383,7 @@ var template string = `<!DOCTYPE html>
 </body>
 </html>`
 
-func getToken(ctx context.Context, c oauth2.Config) (*oauth2.Token, error) {
+func getToken(ctx context.Context, c oauth2.Config, authURLSuffix string) (*oauth2.Token, error) {
 	state := oauth2.GenerateVerifier()
 	queries := make(chan url.Values)
 	handler := http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
@@ -420,19 +426,23 @@ func getToken(ctx context.Context, c oauth2.Config) (*oauth2.Token, error) {
 	defer server.Close()
 	verifier := oauth2.GenerateVerifier()
 	authCodeURL := c.AuthCodeURL(state, oauth2.S256ChallengeOption(verifier))
+	authCodeURL += authURLSuffix
 	fmt.Fprintf(os.Stderr, "Please complete authentication in your browser...\n%s\n", authCodeURL)
 	var open string
+	var p []string
 	switch runtime.GOOS {
 	case "windows":
-		open = "start"
+		open = "rundll32"
+		p = append(p, "url.dll,FileProtocolHandler")
 	case "darwin":
 		open = "open"
 	default:
 		open = "xdg-open"
 	}
+	p = append(p, authCodeURL)
 	// TODO: wait for server to start before opening browser
 	if _, err := exec.LookPath(open); err == nil {
-		err = exec.Command(open, authCodeURL).Run()
+		err = exec.Command(open, p...).Run()
 		if err != nil {
 			return nil, err
 		}
